@@ -5,13 +5,13 @@ from dagster_k8s.job import UserDefinedDagsterK8sConfig
 def test_job_serialization():
 
     cfg = DagsterK8sJobConfig(
-        job_image='test/foo:latest',
-        dagster_home='/opt/dagster/dagster_home',
-        image_pull_policy='Always',
-        image_pull_secrets=[{'name': 'my_secret'}],
+        job_image="test/foo:latest",
+        dagster_home="/opt/dagster/dagster_home",
+        image_pull_policy="Always",
+        image_pull_secrets=[{"name": "my_secret"}],
         service_account_name=None,
-        instance_config_map='some-instance-configmap',
-        postgres_password_secret='some-secret-name',
+        instance_config_map="some-instance-configmap",
+        postgres_password_secret="some-secret-name",
         env_config_maps=None,
         env_secrets=None,
     )
@@ -22,8 +22,8 @@ def test_user_defined_k8s_config_serialization():
     cfg = UserDefinedDagsterK8sConfig(
         container_config={
             "resouces": {
-                'requests': {'cpu': '250m', 'memory': '64Mi'},
-                'limits': {'cpu': '500m', 'memory': '2560Mi'},
+                "requests": {"cpu": "250m", "memory": "64Mi"},
+                "limits": {"cpu": "500m", "memory": "2560Mi"},
             }
         },
         pod_template_spec_metadata={"key": "value"},
